  % This code simply asks for user to input the frequency,
  % temperature, pressure, relative humidity and cloud liquid
  % water and calls the absorb subroutine to get the atmospheric
  % extinction (really absorption since there is no scattering)

  function ATM_EXT=absorb(FREQY, TEMP, PRES, W, CWC)

  %Convert retrieval quantities to parameters needed by Liebe93

   %FREQY : frequency in GHz
   %TEMP : Temperature in Kelvin
   %PRES : total pressure in hPa
   %W    : water vapor mass mixing ratio in kg/kg
   %CWC  : cloud water content in g/m^3

  F    = FREQY            ;% frequency [GHz]    
  Tc   = TEMP - 273.15    ;% temperature [C]
  Pb   = PRES*0.1         ;% total pressure [kPa]
  E    = W * Pb/(0.622 + W) ;% partial pressure of water vapor [kPa]
  R    = CWC              ;% cloud water content [g/m^3]           
  ATM_EXT =  MPM93(F, Pb, E, Tc, R);